@@ -1,6 +1,3 @@
-import sys
-from lib2to3 import refactor
-
 
 lib2to3_fix_names = set([
     'lib2to3.fixes.fix_apply',
@@ -37,6 +34,8 @@ six_fix_names = set([
     'libmodernize.fixes.fix_map',
     'libmodernize.fixes.fix_next',
     'libmodernize.fixes.fix_range',
+    'libmodernize.fixes.fix_raise_six',
     'libmodernize.fixes.fix_unicode',
     'libmodernize.fixes.fix_zip',
+    'libmodernize.fixes.fix_metaclass'
     ])
